==> hoogle-5.0.17.5-18-x86_64.pkg.tar.xz: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hoogle
version: 5.0.17.5
id: hoogle-5.0.17.5-JwbTZrDQPNyAAP1NfGe3Pi
key: hoogle-5.0.17.5-JwbTZrDQPNyAAP1NfGe3Pi
license: BSD-3-Clause
copyright: Neil Mitchell 2004-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: http://hoogle.haskell.org/
synopsis: Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.
category: Development
abi: d4ee26098748b1435c8e38390259af05
exposed: True
exposed-modules:
    Hoogle
hidden-modules: Paths_hoogle Action.CmdLine Action.Generate
                Action.Search Action.Server Action.Test Input.Cabal Input.Download
                Input.Haddock Input.Item Input.Reorder Input.Set Input.Settings
                Output.Items Output.Names Output.Tags Output.Types Query
                General.Conduit General.IString General.Log General.Store
                General.Str General.Template General.Timing General.Util
                General.Web
import-dirs: /usr/lib/ghc-8.6.4/site-local/hoogle-5.0.17.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/hoogle-5.0.17.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hoogle
hs-libraries: HShoogle-5.0.17.5-JwbTZrDQPNyAAP1NfGe3Pi
include-dirs: /usr/lib/ghc-8.6.4/site-local/hoogle-5.0.17.5/include
includes:
    include.h
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl base-4.12.0.0 binary-0.8.6.0
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    conduit-1.3.1.1-FTcpSH31Ql3KtGJaaDZQpS
    conduit-extra-1.3.1.1-KcumXRXf8UFJSbEnt8yrMU
    connection-0.2.8-5vt7jiStikv6lQgQ4VIcQf containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0
    extra-1.6.14-5Tswu2tbShKGyB9aok2v7q filepath-1.4.2.1
    foundation-0.0.23-3KpOIVglyMrCenUbF76lmv
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    haskell-src-exts-1.21.0-4yXVxxTytMuGcSoXAiIDbP
    http-conduit-2.3.6.1-Qh5SUv6RYiPFiCLdYyDt
    http-types-0.12.3-7ETbM18iSLZB08qGmmgPmt
    js-flot-0.8.3-LF7vQ1kAGl41Nl58RwjSyK
    js-jquery-3.3.1-Aa7iHwlQycc8WdqWDByNXn
    mmap-0.5.9-DPtA2NM6pwvChiGDibkbhO
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    process-extras-0.7.4-897zTeAGIZX4b7ZDKVFSuu
    resourcet-1.2.2-5WRYEUs9Kel3m2rSVevxcM
    storable-tuple-0.0.3.3-5yTCOGBTAneKgdgfNyl8qn
    tar-0.5.1.0-GcqFpTqelp4Lmy6ZbjHbS7 template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    uniplate-1.6.12-D1B9e4S36uhTArFMKIWAf
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    wai-3.2.2-7UZCsmzPTqFA7VskjtEotY
    wai-logger-2.3.4-4ejuhiJHJxRK3doVXURMNX
    warp-3.2.26-4Z54Y616a5OBqJ9CXkVTYc
    warp-tls-3.2.4.3-5msGrm0ROFDJ0tSRJdBoRH
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html: /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hoogle-5.0.17.5-19-x86_64.pkg.tar.xz: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hoogle
version: 5.0.17.5
id: hoogle-5.0.17.5-AG6KHDSy2seHT7xqfK78mQ
key: hoogle-5.0.17.5-AG6KHDSy2seHT7xqfK78mQ
license: BSD-3-Clause
copyright: Neil Mitchell 2004-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: http://hoogle.haskell.org/
synopsis: Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.
category: Development
abi: efe05576decab8f233440dc63143883a
exposed: True
exposed-modules:
    Hoogle
hidden-modules: Paths_hoogle Action.CmdLine Action.Generate
                Action.Search Action.Server Action.Test Input.Cabal Input.Download
                Input.Haddock Input.Item Input.Reorder Input.Set Input.Settings
                Output.Items Output.Names Output.Tags Output.Types Query
                General.Conduit General.IString General.Log General.Store
                General.Str General.Template General.Timing General.Util
                General.Web
import-dirs: /usr/lib/ghc-8.6.4/site-local/hoogle-5.0.17.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/hoogle-5.0.17.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hoogle
hs-libraries: HShoogle-5.0.17.5-AG6KHDSy2seHT7xqfK78mQ
include-dirs: /usr/lib/ghc-8.6.4/site-local/hoogle-5.0.17.5/include
includes:
    include.h
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl base-4.12.0.0 binary-0.8.6.0
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    conduit-1.3.1.1-FTcpSH31Ql3KtGJaaDZQpS
    conduit-extra-1.3.1.1-KcumXRXf8UFJSbEnt8yrMU
    connection-0.2.8-5vt7jiStikv6lQgQ4VIcQf containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0
    extra-1.6.14-5Tswu2tbShKGyB9aok2v7q filepath-1.4.2.1
    foundation-0.0.23-3KpOIVglyMrCenUbF76lmv
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    haskell-src-exts-1.21.0-4yXVxxTytMuGcSoXAiIDbP
    http-conduit-2.3.6.1-Qh5SUv6RYiPFiCLdYyDt
    http-types-0.12.3-7ETbM18iSLZB08qGmmgPmt
    js-flot-0.8.3-LF7vQ1kAGl41Nl58RwjSyK
    js-jquery-3.3.1-AsG4ZX3kbbzHXCUnLbkFzf
    mmap-0.5.9-DPtA2NM6pwvChiGDibkbhO
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    process-extras-0.7.4-897zTeAGIZX4b7ZDKVFSuu
    resourcet-1.2.2-5WRYEUs9Kel3m2rSVevxcM
    storable-tuple-0.0.3.3-5yTCOGBTAneKgdgfNyl8qn
    tar-0.5.1.0-GcqFpTqelp4Lmy6ZbjHbS7 template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    uniplate-1.6.12-D1B9e4S36uhTArFMKIWAf
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    wai-3.2.2-7UZCsmzPTqFA7VskjtEotY
    wai-logger-2.3.4-4ejuhiJHJxRK3doVXURMNX
    warp-3.2.26-4Z54Y616a5OBqJ9CXkVTYc
    warp-tls-3.2.4.3-5msGrm0ROFDJ0tSRJdBoRH
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html: /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
